Index: tests/html/isolates_test.dart |
diff --git a/tests/html/isolates_test.dart b/tests/html/isolates_test.dart |
index 608593f93fa4ed2b3c7fdc8c4333b9ce886c0c02..1320d226dd0d1c14794be10871f54fd8a9f280a8 100644 |
--- a/tests/html/isolates_test.dart |
+++ b/tests/html/isolates_test.dart |
@@ -2,7 +2,7 @@ library IsolatesTest; |
import '../../pkg/unittest/lib/unittest.dart'; |
import '../../pkg/unittest/lib/html_config.dart'; |
import 'dart:html'; |
-import 'dart:json'; |
+import 'dart:convert'; |
import 'dart:isolate' as isolate; |
String responseFor(message) => 'response for $message'; |
@@ -19,8 +19,8 @@ void isolateEntry() { |
return; |
} |
- // Check that JSON library was loaded to isolate. |
- stringify([1, 2, 3]); |
+ // Check that convert library was loaded to isolate. |
+ JSON.encode([1, 2, 3]); |
isolate.port.receive((message, replyTo) { |
replyTo.send(responseFor(message), null); |